@@ -571,32 +571,6 @@ macro_rules! impl_const {
     };
 }
 
-#[macro_export]
-macro_rules! impl_sqrt {
-    ($lhs:ty, $res:ty) => {
-        impl Sqrt<$res> for $lhs {
-            fn sqrt(self) -> $res {
-                if self.power % 2 == 0 {
-                    <$res>::from_exponential(self.multiplier.sqrt(), self.power / 2)
-                } else {
-                    <$res>::from_exponential(
-                        self.multiplier.sqrt() * 10_f64.sqrt(),
-                        (self.power - 1) / 2,
-                    )
-                }
-            }
-        }
-        #[cfg(feature = "pyo3")]
-        #[pymethods]
-        impl $lhs {
-            #[pyo3(name = "sqrt")]
-            fn sqrt_py(&self) -> $res {
-                self.sqrt()
-            }
-        }
-    };
-}
-
 #[macro_export]
 macro_rules! impl_div_with_self_to_f64 {
     ($lhs:ty) => {
@@ -833,11 +807,57 @@ macro_rules! impl_div {
     };
 }
 
+#[macro_export]
+macro_rules! impl_sqrt {
+    ($lhs:ty, $res:ty) => {
+        impl Sqrt<$res> for $lhs {
+            fn sqrt(self) -> $res {
+                if self.power % 2 == 0 {
+                    <$res>::from_exponential(self.multiplier.sqrt(), self.power / 2)
+                } else {
+                    <$res>::from_exponential(
+                        self.multiplier.sqrt() * 10_f64.sqrt(),
+                        (self.power - 1) / 2,
+                    )
+                }
+            }
+        }
+        #[cfg(feature = "pyo3")]
+        #[pymethods]
+        impl $lhs {
+            #[pyo3(name = "sqrt")]
+            fn sqrt_py(&self) -> $res {
+                self.sqrt()
+            }
+        }
+    };
+}
+
+#[macro_export]
+macro_rules! impl_mul_relation_with_self {
+    ($lhs:ty, $res:ty) => {
+        impl_mul_with_self!($lhs, $res);
+        impl_sqrt!($res, $lhs);
+        impl_div!($res, $lhs, $lhs);
+    };
+}
+
+#[macro_export]
+macro_rules! impl_mul_relation_with_other {
+    ($lhs:ty, $rhs:ty, $res:ty) => {
+        impl_mul!($lhs, $rhs, $res);
+        impl_div!($res, $lhs, $rhs);
+        impl_div!($res, $rhs, $lhs);
+    };
+}
+
 pub mod macros {
     pub use crate::impl_const;
     pub use crate::impl_div;
     pub use crate::impl_div_with_self_to_f64;
     pub use crate::impl_mul;
+    pub use crate::impl_mul_relation_with_other;
+    pub use crate::impl_mul_relation_with_self;
     pub use crate::impl_mul_with_self;
     pub use crate::impl_quantity;
     pub use crate::impl_sqrt;
