@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -45,5 +44,3 @@ impl_const!(Acceleration, g_mars, 3.73, 0);
 
 impl_quantity!(Acceleration, AccelerationUnit, AccelerationUnit::m_ssq);
 impl_div_with_self_to_f64!(Acceleration);
-impl_mul!(Acceleration, Time, Velocity);
-impl_mul!(Acceleration, Mass, Force);
