@@ -1,6 +1,6 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::{AngularVelocity, PhysicsUnit, Time};
+use crate::PhysicsUnit;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -43,4 +43,3 @@ impl_quantity!(
     AngularAccelerationUnit::deg_ssq
 );
 impl_div_with_self_to_f64!(AngularAcceleration);
-impl_mul!(AngularAcceleration, Time, AngularVelocity);
