@@ -1,6 +1,6 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::{Angle, Distance, PhysicsUnit, Time, Velocity};
+use crate::PhysicsUnit;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -43,6 +43,3 @@ impl_quantity!(
     AngularVelocityUnit::deg_s
 );
 impl_div_with_self_to_f64!(AngularVelocity);
-impl_mul!(AngularVelocity, Time, Angle);
-impl_mul!(AngularVelocity, Angle, Time);
-impl_mul!(AngularVelocity, Distance, Velocity);
