@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -35,8 +34,3 @@ impl PhysicsUnit for AreaOfMomentUnit {
 
 impl_quantity!(AreaOfMoment, AreaOfMomentUnit, AreaOfMomentUnit::mhc);
 impl_div_with_self_to_f64!(AreaOfMoment);
-
-impl_div!(AreaOfMoment, Distance, Volume);
-impl_div!(AreaOfMoment, Area, Area);
-impl_div!(AreaOfMoment, Volume, Distance);
-impl_sqrt!(AreaOfMoment, Area);
