@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -35,6 +34,3 @@ impl PhysicsUnit for ComplianceUnit {
 
 impl_quantity!(Compliance, ComplianceUnit, ComplianceUnit::m_N);
 impl_div_with_self_to_f64!(Compliance);
-
-impl_mul!(Compliance, Force, Distance);
-impl_mul!(Compliance, ForceArea, Volume);
