@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -35,10 +34,3 @@ impl PhysicsUnit for ForceAreaUnit {
 
 impl_quantity!(ForceArea, ForceAreaUnit, ForceAreaUnit::Nmsq);
 impl_div_with_self_to_f64!(ForceArea);
-
-impl_div!(ForceArea, Stress, AreaOfMoment);
-impl_div!(ForceArea, AreaOfMoment, Stress);
-impl_div!(ForceArea, Force, Area);
-impl_div!(ForceArea, Area, Force);
-impl_mul!(ForceArea, Distance, ForceVolume);
-impl_mul!(ForceArea, InverseArea, Force);
