@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -42,7 +41,3 @@ impl_quantity!(
     ForcePerDistancePowerFourUnit::N_mmhc
 );
 impl_div_with_self_to_f64!(ForcePerDistancePowerFour);
-
-impl_mul!(ForcePerDistancePowerFour, Volume, Stiffness);
-impl_div!(ForcePerDistancePowerFour, InverseDistance, ForcePerVolume);
-impl_div!(ForcePerDistancePowerFour, ForcePerVolume, InverseDistance);
