@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -42,11 +41,3 @@ impl_quantity!(
     ForcePerVolumeUnit::N_mcb
 );
 impl_div_with_self_to_f64!(ForcePerVolume);
-impl_div!(Force, Volume, ForcePerVolume);
-impl_mul!(ForcePerVolume, Volume, Force);
-impl_mul!(Density, Acceleration, ForcePerVolume);
-impl_mul!(ForcePerVolume, Area, MassPerTimeSquare);
-impl_mul!(ForcePerVolume, Distance, MassPerDistanceTimeSquare);
-impl_mul!(ForcePerVolume, InverseDistance, ForcePerDistancePowerFour);
-impl_div!(ForcePerVolume, Density, Acceleration);
-impl_div!(ForcePerVolume, Acceleration, Density);
