@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -35,4 +34,3 @@ impl PhysicsUnit for ForceVolumeUnit {
 
 impl_quantity!(ForceVolume, ForceVolumeUnit, ForceVolumeUnit::Nmcb);
 impl_div_with_self_to_f64!(ForceVolume);
-impl_div!(ForceVolume, ForceArea, Distance);
