@@ -1,6 +1,6 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
+use crate::Area;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -35,5 +35,4 @@ impl PhysicsUnit for InverseAreaUnit {
 
 impl_quantity!(InverseArea, InverseAreaUnit, InverseAreaUnit::_msq);
 impl_div_with_self_to_f64!(InverseArea);
-impl_sqrt!(InverseArea, InverseDistance);
-impl_mul!(InverseArea, Volume, Distance);
+impl_mul!(InverseArea, Area, f64);
