@@ -50,9 +50,5 @@ impl PhysicsUnit for StressUnit {
 
 impl_quantity!(Stress, StressUnit, StressUnit::MPa);
 impl_div_with_self_to_f64!(Stress);
-impl_mul_with_self!(Stress, StressSquared);
 impl_div!(Stress, Strain, Stress);
 impl_mul!(Stress, Strain, Stress);
-impl_mul!(Stress, AreaOfMoment, ForceArea);
-impl_mul!(Stress, Distance, MassPerTimeSquare);
-impl_mul!(Stress, Volume, ForceDistance);
