@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -39,4 +38,3 @@ impl_quantity!(
     StressSquaredUnit::Nsq_mmhc
 );
 impl_div_with_self_to_f64!(StressSquared);
-impl_div!(StressSquared, Stress, Stress);
