@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -49,5 +48,3 @@ impl_const!(Velocity, c, 2.99792458, 8);
 
 impl_quantity!(Velocity, VelocityUnit, VelocityUnit::m_s);
 impl_div_with_self_to_f64!(Velocity);
-impl_mul!(Velocity, Time, Distance);
-impl_mul!(Velocity, Distance, Time);
