@@ -1,6 +1,5 @@
 use crate::impl_macros::macros::*;
 use crate::prelude::*;
-use crate::quantities::*;
 use ndarray::{Array1, Array2, ArrayView1, ArrayView2};
 use num_traits::identities::Zero;
 use num_traits::FromPrimitive;
@@ -47,5 +46,3 @@ impl PhysicsUnit for VoltageUnit {
 
 impl_quantity!(Voltage, VoltageUnit, VoltageUnit::V);
 impl_div_with_self_to_f64!(Voltage);
-
-impl_mul!(Voltage, Charge, ForceDistance);
