@@ -51,4 +51,21 @@ mod tests {
         f_1.optimize();
         assert_eq!(f_1, Force::zero());
     }
+
+    #[test]
+    fn mul_with_self() {
+        let a = Quantity::AreaQuantity(Area::new(10.0, AreaUnit::msq));
+        let b = (a * a).unwrap();
+        assert_eq!(
+            b.to(Unit::AreaOfMomentUnit(AreaOfMomentUnit::mhc)).unwrap(),
+            100.0
+        );
+    }
+
+    #[test]
+    fn sqrt() {
+        let a = Quantity::AreaOfMomentQuantity(AreaOfMoment::new(25.0, AreaOfMomentUnit::mhc));
+        let b = a.sqrt().unwrap();
+        assert!((b.to(Unit::AreaUnit(AreaUnit::msq)).unwrap() - 5.0).abs() < 1E-10);
+    }
 }
